<div align="center">
    <img src="docs/_static/logo-light.png">
</div>

---

SecretFlow is a unified framework for privacy-preserving data intelligence and machine learning. To achieve this goal,
it provides:

- An abstract device layer consists of plain devices and secret devices which encapsulate various cryptographic protocols.
- A device flow layer modeling higher algorithms as device object flow and DAG.
- An algorithm layer to do data analysis and machine learning with horizontal or vertical partitioned data.
- A workflow layer that seamlessly integrates data processing, model training, and hyperparameter tuning.

<div align="center">
    <img src="docs/_static/secretflow_arch.svg">
</div>

## Install

Please check [INSTALLATION.md](./INSTALLATION.md)

## Deployment

Please check [DEPLOYMENT.md](./DEPLOYMENT.md)

## CONTRIBUTING

Please check [CONTRIBUTING.md](./CONTRIBUTING.md)

## Disclaimer
Non-release versions of SecretFlow are prohibited to use in any production environment due to possible bugs, glitches, lack of functionality, security issues or other problems.
